# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.connectors_v1_api import ConnectorsV1Api


class TestConnectorsV1Api(unittest.TestCase):
    """ConnectorsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = ConnectorsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_connector(self) -> None:
        """Test case for delete_connector

        Delete Connector
        """
        pass

    def test_get_connector(self) -> None:
        """Test case for get_connector

        Get Connector
        """
        pass

    def test_get_connectors(self) -> None:
        """Test case for get_connectors

        List Connectors
        """
        pass

    def test_get_sensitive_connector(self) -> None:
        """Test case for get_sensitive_connector

        Get Sensitive Connector
        """
        pass

    def test_patch_connector(self) -> None:
        """Test case for patch_connector

        Update Connector
        """
        pass

    def test_post_connector(self) -> None:
        """Test case for post_connector

        Create Connector
        """
        pass

    def test_put_connector_check_results(self) -> None:
        """Test case for put_connector_check_results

        Persist Connector Check Results
        """
        pass


if __name__ == '__main__':
    unittest.main()
